@@ -78,7 +78,8 @@ def combine_intermediate_file(intermediate_participant_path, date_in_study):
         try:
             df_day = pd.read_csv(csv_path)
         except pd.errors.EmptyDataError:
-            raise Exception("pandas.errors.EmptyDataError (phone_lock) : " + csv_path)
+            continue
+            #raise Exception("pandas.errors.EmptyDataError (phone_lock) : " + csv_path)
 
         if df_day.shape[0] > 0:
             df_day['Participant_ID'] = [participant_id] * df_day.shape[0]
